@@ -18,7 +18,8 @@ class LoadDataKline:
         logging.info('Loading', self.exchange.id, 'markets...')
         self.exchange.load_markets()
         for sym in self.exchange.symbols:
-            print(sym)
+            if ':' not in sym:
+                print(sym)
         logging.info('Loaded', self.exchange.id, 'markets.')
 
     def load(self, symbol, timeframe='1m', max_retries=3):
@@ -29,12 +30,12 @@ class LoadDataKline:
         timedelta = limit * timeframe_duration_in_ms
         result_dictionary = {}
 
-        for _ in tqdm(range(10000)):
+        pbar = tqdm(range(1000), desc=symbol)
+        for _ in pbar:
             fetch_since = earliest_timestamp - timedelta
             result = self.exchange.fetch_ohlcv(symbol, timeframe, fetch_since, limit)
+            pbar.set_postfix({'fetch_since': self.exchange.iso8601(result[0][0])})
 
-            print('Fetched', len(result), self.exchange.id, symbol, timeframe, 'candles from',
-                  self.exchange.iso8601(result[0][0]), 'to', self.exchange.iso8601(result[-1][0]))
             if len(result) == 0:
                 continue
 
@@ -51,8 +52,5 @@ class LoadDataKline:
 
 
 exchan = LoadDataKline(ccxt.okex())
-
-symbol = 'BTC/USDT'
-
-ohlcvs = exchan.load(symbol)
-print('Done.')
+# exchan.load('BTC/USDT')
+exchan.load_all()
